@@ -1,13 +1,18 @@
-#ifndef ensemble_Matrix_h
-#define ensemble_Matrix_h
+#ifndef mRMRe_Matrix_h
+#define mRMRe_Matrix_h
 
-#include <omp.h>
 #include <vector>
 
 class Matrix
 {
+private:
+    Matrix(const Matrix&);
+
+    Matrix&
+    operator=(const Matrix&);
+
 protected:
-    float* const mpData;
+    double* const mpData;
     unsigned int const mRowCount;
     unsigned int const mColumnCount;
     bool const mHasAllocation;
@@ -19,15 +24,15 @@ public:
     Matrix(unsigned int const size, unsigned int const rowCount, unsigned int const columnCount);
 
     explicit
-    Matrix(float* const pData, unsigned int const rowCount, unsigned int const columnCount);
+    Matrix(double* const pData, unsigned int const rowCount, unsigned int const columnCount);
 
     virtual
     ~Matrix();
 
-    virtual float&
+    virtual double&
     at(unsigned int const i, unsigned int const j);
 
-    float const&
+    virtual double const&
     at(unsigned int const i, unsigned int const j) const;
 
     unsigned int const
@@ -35,9 +40,6 @@ public:
 
     unsigned int const
     getRowCount() const;
-
-    std::vector<float> const
-    getVectorizedData() const;
 };
 
-#endif /* ensemble_Matrix_h */
+#endif /* mRMRe_Matrix_h */
